@@ -540,11 +540,16 @@ class ContinuumNormalizationMatch(ContinuumNormalizationAbstract):
             tell = sme.telluric[segments][m]
             yp *= tell
 
+        # TODO: what should this be?
+        u = u + 10000 * np.nanmedian(u) * (np.nanpercentile(y, 95) - y) ** 2
+
         deg = sme.cscale_degree
         p0 = sme.cscale[segments]
         func = lambda p: (yp * np.polyval(p, xs) - y) / u
         try:
-            res = least_squares(func, x0=p0, loss="soft_l1", method="trf", xtol=None)
+            res = least_squares(
+                func, x0=p0, loss="soft_l1", method="trf", xtol=None, x_scale="jac"
+            )
             popt = res.x
         except RuntimeError as ex:
             logger.warning("Could not determine the continuum")
@@ -720,14 +725,14 @@ def cross_correlate_segment(x_obs, y_obs, x_syn, y_syn, mask, rv_bounds):
 
     # Normalize both spectra
     y_obs_tmp = y_obs - np.min(y_obs)
-    y_obs_tmp /= np.max(y_obs_tmp)
-    y_obs_tmp -= np.nanpercentile(y_obs_tmp, 95)
+    y_obs_tmp /= np.nanpercentile(y_obs_tmp, 95)
+    y_obs_tmp -= 1
     y_tmp_tmp = y_tmp - np.min(y_tmp)
-    y_tmp_tmp /= np.max(y_tmp_tmp)
-    y_tmp_tmp -= np.nanpercentile(y_tmp_tmp, 95)
+    y_tmp_tmp /= np.nanpercentile(y_tmp_tmp, 95)
+    y_tmp_tmp -= 1
 
     # Perform cross correaltion between normalized spectra
-    corr = correlate(y_obs_tmp, y_tmp_tmp, mode="same", method="direct")
+    corr = correlate(y_obs_tmp, y_tmp_tmp, mode="same")
 
     # Determine the radial velocity offset
     # and only retain the area within the bounds
