@@ -11,11 +11,11 @@ from os.path import splitext
 import numpy as np
 from scipy.constants import speed_of_light
 from scipy.optimize import OptimizeWarning, least_squares
+from scipy.optimize._numdiff import approx_derivative
 from scipy.stats import norm
 from tqdm import tqdm
 
 from . import __file_ending__
-from ._numdiff import approx_derivative
 from .abund import Abund
 from .atmosphere.atmosphere import AtmosphereError
 from .atmosphere.krzfile import KrzFile
@@ -49,8 +49,8 @@ class SME_Solver:
         self.restore = restore
 
         # For displaying the progressbars
-        # self.progressbar = None
-        # self.progressbar_jacobian = None
+        self.progressbar = None
+        self.progressbar_jacobian = None
 
     @property
     def nparam(self):
@@ -171,11 +171,11 @@ class SME_Solver:
         resid = np.nan_to_num(resid, copy=False)
 
         # Update progress bars
-        # if isJacobian:
-        #     self.progressbar_jacobian.update(1)
-        # else:
-        #     self.progressbar.total += 1
-        #     self.progressbar.update(1)
+        if isJacobian:
+            self.progressbar_jacobian.update(1)
+        else:
+            self.progressbar.total += 1
+            self.progressbar.update(1)
 
         if not isJacobian:
             # Save result for jacobian
@@ -196,7 +196,7 @@ class SME_Solver:
         The calculation is the same as "3-point"
         but we can tell residuals that we are within a jacobian
         """
-        # self.progressbar_jacobian.reset()
+        self.progressbar_jacobian.reset()
 
         # Here we replace the scipy version of approx_derivative with our own
         # The only difference being that we use Multiprocessing for the jacobian
@@ -646,14 +646,12 @@ class SME_Solver:
         logger.debug("Bounds: %s", bounds)
 
         if (
-            sme.wran.min() * (1 - 100 / 3e5) > sme.linelist.wlcent.min()
-            or sme.wran.max() * (1 + 100 / 3e5) < sme.linelist.wlcent.max()
+            sme.wran.min() * (1 - 100 / clight) > sme.linelist.wlcent.min()
+            or sme.wran.max() * (1 + 100 / clight) < sme.linelist.wlcent.max()
         ):
             logger.warning(
                 "The linelist extends far beyond the requested wavelength range."
-                " This will slow down the calculation, consider using only relevant lines"
-            )
-            logger.warning(
+                " This will slow down the calculation, consider using only relevant lines\n"
                 f"Wavelength range: {sme.wran.min()} - {sme.wran.max()} Å"
                 f" ; Linelist range: {sme.linelist.wlcent.min()} - {sme.linelist.wlcent.max()} Å"
             )
@@ -665,8 +663,8 @@ class SME_Solver:
 
         # Do the heavy lifting
         if self.nparam > 0:
-            # self.progressbar = tqdm(desc="Iteration", total=0)
-            # self.progressbar_jacobian = tqdm(desc="Jacobian", total=len(p0))
+            self.progressbar = tqdm(desc="Iteration", total=0)
+            self.progressbar_jacobian = tqdm(desc="Jacobian", total=len(p0))
             with print_to_log():
                 res = least_squares(
                     self.__residuals,
@@ -681,8 +679,8 @@ class SME_Solver:
                     args=(sme, spec, uncs, mask),
                     kwargs={"bounds": bounds, "segments": segments},
                 )
-            # self.progressbar.close()
-            # self.progressbar_jacobian.close()
+            self.progressbar.close()
+            self.progressbar_jacobian.close()
             # The returned jacobian is "scaled for robust loss function"
             res.jac = self._last_jac
             for i, name in enumerate(self.parameter_names):
