@@ -439,7 +439,7 @@ class Synthesizer:
         reuse_wavelength_grid,
         dll_id=None,
     ):
-        for il in segments:
+        for il in tqdm(segments, desc="Segments", leave=False):
             wmod[il], smod[il], cmod[il] = self.synthesize_segment(
                 sme,
                 il,
@@ -624,7 +624,7 @@ class Synthesizer:
             for i in range(sme.nseg):
                 mask = ~np.isfinite(sme.spec[i])
                 mask |= sme.uncs[i] == 0
-                sme.mask[i, mask] = sme.mask_values["bad"]
+                sme.mask[i][mask] = sme.mask_values["bad"]
 
         if radial_velocity_mode != "robust" and (
             "cscale" not in sme or "vrad" not in sme
